<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">



	<!-- specify xhtml output -->
	<xsl:output method="xml" encoding="utf-8" indent="yes" omit-xml-declaration="yes"/>

	<!-- this is needed so that whitespace nodes
		in page/*.xml are not seen as text-keys -->
	<xsl:strip-space elements="*"/>


	<xsl:template match="/">
		<html>
			<head>
				<title>Error Report</title>
				<style>.attribute-title{ min-width: 200px; }</style>
			</head>
			<body>
				<span style="position:absolute;">Test Date:</span>		<span style="margin-left: 150px;"><xsl:value-of select="/test/@time"/></span><br/>
				<span style="position:absolute;">Test Passed:</span>	<span style="margin-left: 150px;"><xsl:value-of select="/test/@passed"/></span><br/>
				<span style="position:absolute;">SVN info:</span>	<pre style="margin-left: 150px;"><xsl:value-of select="/test/svn-info"/></pre><br/>

				<xsl:if test="/test/@passed='no'">

					<span style="position: absolute;">Errors:</span>		<span style="margin-left: 150px;"><xsl:value-of select="/test/@errors"/></span><br/>
					<xsl:for-each select="/test/error">
						<div style="border: 1px solid black;padding:0;margin:10px;background-color: #ffd;">
							<h2  style="padding:0; margin:5px; font-weight:bold; font-size: 14pt;">Error</h2>
							<h6 style="padding:0; margin:5px; font-weight: normal; font-size: 12pt;">Location:</h6>
							<pre style="padding:5px; margin:0; margin-left:30px;">
								<xsl:for-each select="location/node"><xsl:if test="position() &gt; 1"> at </xsl:if><xsl:value-of select="normalize-space(.)"/><xsl:if test="position() &lt; last()"><br/></xsl:if></xsl:for-each></pre>

							<xsl:variable name="error-message">
								<xsl:call-template name="substitute">
									<xsl:with-param name="string"><xsl:value-of select="message"/></xsl:with-param>
								</xsl:call-template>
							</xsl:variable>
							<br/>
							<h6 style="padding:0; margin:5px; font-weight: normal; font-size: 12pt;">Error Message:</h6>
							<pre style="padding:10px; margin:0; margin-left:30px;"><xsl:value-of disable-output-escaping="yes" select="normalize-space($error-message)"/></pre>
						</div>
					</xsl:for-each>
				</xsl:if>
			</body>
		</html>
	</xsl:template>

	<xsl:template name="substitute">
	   <xsl:param name="string" />
	   <xsl:param name="from" select="'&#xA;'" />
	   <xsl:param name="to">&lt;br/&gt;</xsl:param>
	   <xsl:choose>
	      <xsl:when test="contains($string, $from)">
	         <xsl:value-of select="substring-before($string, $from)" />
	         <xsl:copy-of select="$to" />
	         <xsl:call-template name="substitute">
	            <xsl:with-param name="string"
	                            select="substring-after($string, $from)" />
	            <xsl:with-param name="from" select="$from" />
	            <xsl:with-param name="to" select="$to" />
	         </xsl:call-template>
	      </xsl:when>
	      <xsl:otherwise>
	         <xsl:value-of select="$string" />
	      </xsl:otherwise>
	   </xsl:choose>
	</xsl:template>

	<!-- copy xhtml tags directly, except when certain special tags are seen -->
	<xsl:template name="traverse">
		<xsl:param name="root" select="/"/>

		<xsl:for-each select="node()">

			<xsl:choose>

				<!-- if a text node -->
				<xsl:when test="self::text()">
					<xsl:value-of select="."/>
				</xsl:when>

				<!-- if a normal node -->
				<xsl:when test="self::*">
					<xsl:if test="not( @succeeded='yes' )">
						<xsl:variable name="element-name" select="name()"/>
						<xsl:element name="{$element-name}">
							<xsl:for-each select="@*">
								<xsl:variable name="attribute-name" select="name()"/>
								<xsl:attribute name="{$attribute-name}"><xsl:value-of select="."/></xsl:attribute>
							</xsl:for-each>
							<xsl:call-template name="traverse"><xsl:with-param name="root" select="."/></xsl:call-template>
						</xsl:element>
					</xsl:if>

				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
